import { useState } from "react";
import { FANTOM } from "../../constants";
import { Link, SvgIcon, Popper, Button, Paper, Typography, Divider, Box, Fade, Slide } from "@material-ui/core";
import { ReactComponent as InfoIcon } from "../../assets/icons/info-fill.svg";
import { ReactComponent as ArrowUpIcon } from "../../assets/icons/arrow-up.svg";
import { ReactComponent as shecTokenImg } from "../../assets/tokens/SHEC.svg";
// import LuxorIcon from "../../assets/tokens/LUX.png";
import { ReactComponent as wshecTokenImg } from "../../assets/tokens/wsHEC.svg";
import { ReactComponent as TorSVG } from "../../assets/tokens/TOR.svg";
import { NavLink } from "react-router-dom";

import "./hecmenu.scss";
import { dai } from "src/helpers/all-bonds/dai-bonds";
import { useWeb3Context } from "../../hooks/web3Context";

import LuxImg from "src/assets/tokens/LUX.png";
import SHecImg from "src/assets/tokens/SHEC.png";
import wsHecImg from "src/assets/tokens/wsHEC.png";
import sorImg from "src/assets/tokens/TOR.png";

const addTokenToWallet = (tokenSymbol, tokenAddress) => async () => {
  if (window.ethereum) {
    const host = window.location.origin;
    // NOTE (appleseed): 33T token defaults to sHEC logo since we don't have a 33T logo yet
    let tokenPath, decimals;
    // if (tokenSymbol === "LUX") {

    // } ? HecImg : SHecImg;
    switch (tokenSymbol) {
      case "wsHEC":
        tokenPath = wsHecImg;
        decimals = 9;
        break;
      case "LUX":
        tokenPath = LuxImg;
        decimals = 9;
        break;
      case "TOR":
        tokenPath = sorImg;
        decimals = 18;
        break;
      default:
        tokenPath = SHecImg;
        decimals = 9;
    }
    const imageURL = `${host}/${tokenPath}`;
    try {
      await window.ethereum.request({
        method: "wallet_watchAsset",
        params: {
          type: "ERC20",
          options: {
            address: tokenAddress,
            symbol: tokenSymbol,
            decimals: decimals,
            image: imageURL,
          },
        },
      });
    } catch (error) {
      console.log(error);
    }
  }
};

function HecMenu() {
  const [anchorEl, setAnchorEl] = useState(null);
  const isEthereumAPIAvailable = window.ethereum;

  const { chainID } = useWeb3Context();
  const usingFantom = chainID === 0xfa;
  const network = FANTOM;
  const LUM_ADDRESS = network.LUM_ADDRESS;
  const WLUM_ADDRESS = network.WLUM_ADDRESS;
  const LUX_ADDRESS = network.LUX_ADDRESS;
  const USDC_ADDRESS = network.USDC_ADDRESS;
  const SOR_ADDRESS = network.SOR_ADDRESS;

  const handleClick = event => {
    setAnchorEl(anchorEl ? null : event.currentTarget);
  };

  const open = Boolean(anchorEl);
  const id = "hec-popper";
  const daiAddress = dai.getAddressForReserve(0xfa);
  return (
    <Box
      component="div"
      onMouseEnter={e => handleClick(e)}
      onMouseLeave={e => handleClick(e)}
      id="hec-menu-button-hover"
    >
      <Button id="hec-menu-button" size="large" variant="contained" color="secondary" title="LUX" aria-describedby={id}>
        <SvgIcon component={InfoIcon} color="primary" />
        <Typography>LUX</Typography>
      </Button>

      <Popper id={id} open={open} anchorEl={anchorEl} placement="bottom-start" transition>
        {({ TransitionProps }) => {
          return (
            <Fade {...TransitionProps} timeout={100}>
              <Paper className="hec-menu" elevation={1}>
                <Box component="div" className="buy-tokens">
                  <Link
                    href={`https://exchange.soulswap.finance/#/add/${USDC_ADDRESS}/${LUX_ADDRESS}`}
                    target="_blank"
                    rel="noreferrer"
                  >
                    <Button size="large" variant="contained" color="secondary" fullWidth>
                      <Typography align="left">
                        Buy on SoulSwap <SvgIcon component={ArrowUpIcon} htmlColor="#A3A3A3" />
                      </Typography>
                    </Button>
                  </Link>

                  <Link component={NavLink} to="/wrap" style={{ textDecoration: "none" }}>
                    <Button size="large" variant="contained" color="secondary" fullWidth>
                      <Typography align="left">Wrap LUM</Typography>
                    </Button>
                  </Link>
                </Box>

                {isEthereumAPIAvailable ? (
                  <Box className="add-tokens">
                    <Divider color="secondary" />
                    <p>ADD TOKEN TO WALLET</p>
                    <Box display="flex" flexDirection="row" justifyContent="space-between">
                      <Button
                        variant="contained"
                        color="secondary"
                        disabled={!usingFantom}
                        onClick={addTokenToWallet("LUX", LUX_ADDRESS)}
                      >
                      <img className="branding-header-icon" src={LuxorIcon} alt="LuxorMoney" />

                        <Typography variant="body1">LUX</Typography>
                      </Button>
                      <Button
                        variant="contained"
                        color="secondary"
                        disabled={!usingFantom}
                        onClick={addTokenToWallet("sHEC", LUM_ADDRESS)}
                      >
                      <img className="branding-header-icon" src={LuxorIcon} alt="LuxorMoney" />

                        <Typography variant="body1">LUM</Typography>
                      </Button>
                      <Button
                        variant="contained"
                        color="secondary"
                        disabled={!usingFantom}
                        onClick={addTokenToWallet("WLUM", WLUM_ADDRESS)}
                      >
                        <SvgIcon
                          component={wshecTokenImg}
                          viewBox="0 0 100 100"
                          style={{ height: "25px", width: "25px" }}
                        />
                        <Typography variant="body1">WLUM</Typography>
                      </Button>
                      <Button
                        variant="contained"
                        color="secondary"
                        disabled={!usingFantom}
                        onClick={addTokenToWallet("SOR", SOR_ADDRESS)}
                      >
                        <TorSVG style={{ height: "25px", width: "25px" }} />

                        <Typography variant="body1">SOR</Typography>
                      </Button>
                    </Box>
                  </Box>
                ) : null}
              </Paper>
            </Fade>
          );
        }}
      </Popper>
    </Box>
  );
}

export default HecMenu;
