import { NetworkID, CustomBond, BondType } from "src/lib/Bond";
import { FANTOM } from "src/constants";
import { ReactComponent as wFTMImg } from "src/assets/tokens/wFTM.svg";
import { abi as FtmBondContract } from "src/abi/bonds/FtmContract.json";
import { abi as FtmBondContractV2 } from "src/abi/bonds/FtmContractV2.json";
import { abi as ierc20Abi } from "src/abi/IERC20.json";

export const ftm = new CustomBond({
  name: "ftm",
  displayName: "wFTM",
  lpUrl: "",
  bondType: BondType.StableAsset,
  bondToken: "WFTM",
  bondIconSvg: wFTMImg,
  isOld: true,
  bondContractABI: FtmBondContract,
  reserveContract: ierc20Abi, // The Standard ierc20Abi since they're normal tokens
  networkAddrs: {
    [NetworkID.Fantom]: {
      bondAddress: "0x13729e99A7b77469f7FD204495a7b49e25e8444a",
      reserveAddress: FANTOM.WFTM_ADDRESS,
    },
    [NetworkID.Testnet]: {
      bondAddress: "",
      reserveAddress: "",
    },
  },
  customTreasuryBalanceFunc: async function (this: CustomBond, networkID, provider) {
    const ethBondContract = this.getContractForBond(networkID, provider);
    let ethPrice = await ethBondContract.assetPrice();
    ethPrice = ethPrice / Math.pow(10, 8);
    const token = this.getContractForReserve(networkID, provider);
    let ftmAmount = await token.balanceOf(FANTOM.TREASURY_ADDRESS);
    ftmAmount = ftmAmount / Math.pow(10, 18);
    return ftmAmount * ethPrice;
  },
});
export const ftm_7 = new CustomBond({
  name: "ftm_7",
  displayName: "wFTM",
  lpUrl: "",
  bondType: BondType.StableAsset,
  bondToken: "WFTM",
  // fourAddress: "0xE07fC828f104c523D1E16eBe93f958a521A9f8b3",
  bondIconSvg: wFTMImg,
  bondContractABI: FtmBondContractV2,
  reserveContract: ierc20Abi, // The Standard ierc20Abi since they're normal tokens
  networkAddrs: {
    [NetworkID.Fantom]: {
      bondAddress: "0x376969e00621Ebf685fC3D1F216C00d19B162923",
      reserveAddress: FANTOM.WFTM_ADDRESS,
    },
    [NetworkID.Testnet]: {
      bondAddress: "",
      reserveAddress: "",
    },
  },
  customTreasuryBalanceFunc: async function (this: CustomBond, networkID, provider) {
    const ethBondContract = this.getContractForBond(networkID, provider);
    let ethPrice = await ethBondContract.assetPrice();
    ethPrice = ethPrice / Math.pow(10, 8);
    const token = this.getContractForReserve(networkID, provider);
    let ftmAmount = await token.balanceOf(FANTOM.TREASURY_ADDRESS);
    ftmAmount = ftmAmount / Math.pow(10, 18);
    return ftmAmount * ethPrice;
  },
});
export const ftm_14 = new CustomBond({
  name: "ftm_14",
  displayName: "wFTM",
  lpUrl: "",
  bondType: BondType.StableAsset,
  bondToken: "WFTM",
  // fourAddress: "0xE07fC828f104c523D1E16eBe93f958a521A9f8b3",
  bondIconSvg: wFTMImg,
  bondContractABI: FtmBondContractV2,
  reserveContract: ierc20Abi, // The Standard ierc20Abi since they're normal tokens
  networkAddrs: {
    [NetworkID.Fantom]: {
      bondAddress: "0xc421072646C51FF8983714F28e4253ad8B44bb1E",
      reserveAddress: FANTOM.WFTM_ADDRESS,
    },
    [NetworkID.Testnet]: {
      bondAddress: "",
      reserveAddress: "",
    },
  },
  customTreasuryBalanceFunc: async function (this: CustomBond, networkID, provider) {
    const ethBondContract = this.getContractForBond(networkID, provider);
    let ethPrice = await ethBondContract.assetPrice();
    ethPrice = ethPrice / Math.pow(10, 8);
    const token = this.getContractForReserve(networkID, provider);
    let ftmAmount = await token.balanceOf(FANTOM.TREASURY_ADDRESS);
    ftmAmount = ftmAmount / Math.pow(10, 18);
    return ftmAmount * ethPrice;
  },
});
export const ftm_28 = new CustomBond({
  name: "ftm_28",
  displayName: "wFTM",
  lpUrl: "",
  bondType: BondType.StableAsset,
  bondToken: "WFTM",
  // fourAddress: "0xE07fC828f104c523D1E16eBe93f958a521A9f8b3",
  bondIconSvg: wFTMImg,
  bondContractABI: FtmBondContractV2,
  reserveContract: ierc20Abi, // The Standard ierc20Abi since they're normal tokens
  networkAddrs: {
    [NetworkID.Fantom]: {
      bondAddress: "0x89EA4331183730F289DEAfc926cF0541364F169D",
      reserveAddress: FANTOM.WFTM_ADDRESS,
    },
    [NetworkID.Testnet]: {
      bondAddress: "",
      reserveAddress: "",
    },
  },
  customTreasuryBalanceFunc: async function (this: CustomBond, networkID, provider) {
    const ethBondContract = this.getContractForBond(networkID, provider);
    let ethPrice = await ethBondContract.assetPrice();
    ethPrice = ethPrice / Math.pow(10, 8);
    const token = this.getContractForReserve(networkID, provider);
    let ftmAmount = await token.balanceOf(FANTOM.TREASURY_ADDRESS);
    ftmAmount = ftmAmount / Math.pow(10, 18);
    return ftmAmount * ethPrice;
  },
});
